..
      Copyright 2012 Nicolas Barcet for Canonical

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

=================
Contributor Guide
=================

In the Contributions Guide, you will find documented policies for developing
with Aodh. This includes the processes we use for bugs, contributor onboarding,
core reviewer memberships, and other procedural items.

Overview
========

.. toctree::
   :maxdepth: 2

   architecture
   webapi/index

Developer Documentation
=======================

.. toctree::
   :maxdepth: 2

   install/index
   testing
   contributing
   event-alarm

Appendix
========

.. toctree::
   :maxdepth: 1

   releasenotes/index

.. update index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
